@@ -1,42 +1,20 @@
 package Catalyst::DispatchType::Path;
 
-use Moose;
-extends 'Catalyst::DispatchType';
-
+use strict;
+use base qw/Catalyst::DispatchType/;
 use Text::SimpleTable;
-use Catalyst::Utils;
 use URI;
 
-has _paths => (
-               is => 'rw',
-               isa => 'HashRef',
-               required => 1,
-               default => sub { +{} },
-              );
-
-no Moose;
-
 =head1 NAME
 
 Catalyst::DispatchType::Path - Path DispatchType
 
 =head1 SYNOPSIS
 
-See L<Catalyst::DispatchType>.
+See L<Catalyst>.
 
 =head1 DESCRIPTION
 
-Dispatch type managing full path matching behaviour.  For more information on
-dispatch types, see:
-
-=over 4
-
-=item * L<Catalyst::Manual::Intro> for how they affect application authors
-
-=item * L<Catalyst::DispatchType> for implementation information.
-
-=back
-
 =head1 METHODS
 
 =head2 $self->list($c)
@@ -47,25 +25,15 @@ Debug output for Path dispatch points
 
 sub list {
     my ( $self, $c ) = @_;
-    my $avail_width = Catalyst::Utils::term_width() - 9;
-    my $col1_width = ($avail_width * .50) < 35 ? 35 : int($avail_width * .50);
-    my $col2_width = $avail_width - $col1_width;
-    my $paths = Text::SimpleTable->new(
-       [ $col1_width, 'Path' ], [ $col2_width, 'Private' ]
-    );
-    foreach my $path ( sort keys %{ $self->_paths } ) {
-        foreach my $action ( @{ $self->_paths->{$path} } ) {
-            my $args  = $action->attributes->{Args}->[0];
-            my $parts = defined($args) ? '/*' x $args : '/...';
-
-            my $display_path = "/$path/$parts";
-            $display_path =~ s{/{1,}}{/}g;
-
+    my $paths = Text::SimpleTable->new( [ 35, 'Path' ], [ 36, 'Private' ] );
+    foreach my $path ( sort keys %{ $self->{paths} } ) {
+        my $display_path = $path eq '/' ? $path : "/$path";
+        foreach my $action ( @{ $self->{paths}->{$path} } ) {
             $paths->row( $display_path, "/$action" );
         }
     }
-    $c->log->debug( "Loaded Path actions:\n" . $paths->draw . "\n" )
-      if ( keys %{ $self->_paths } );
+    $c->log->debug( "Loaded Path actions:\n" . $paths->draw )
+      if ( keys %{ $self->{paths} } );
 }
 
 =head2 $self->match( $c, $path )
@@ -79,11 +47,9 @@ first action that matches, if any; if not, returns 0.
 sub match {
     my ( $self, $c, $path ) = @_;
 
-    $path = '/' if !defined $path || !length $path;
+    $path ||= '/';
 
-    my @actions = @{ $self->_paths->{$path} || [] };
-
-    foreach my $action ( @actions ) {
+    foreach my $action ( @{ $self->{paths}->{$path} || [] } ) {
         next unless $action->match($c);
         $c->req->action($path);
         $c->req->match($path);
@@ -123,11 +89,8 @@ sub register_path {
     $path =~ s!^/!!;
     $path = '/' unless length $path;
     $path = URI->new($path)->canonical;
-    $path =~ s{(?<=[^/])/+\z}{};
 
-    $self->_paths->{$path} = [
-        sort { $a->compare($b) } ($action, @{ $self->_paths->{$path} || [] })
-    ];
+    unshift( @{ $self->{paths}{$path} ||= [] }, $action);
 
     return 1;
 }
@@ -155,17 +118,16 @@ sub uri_for_action {
     }
 }
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-Catalyst Contributors, see Catalyst.pm
+Matt S Trout
+Sebastian Riedel, C<sri@cpan.org>
 
 =head1 COPYRIGHT
 
-This library is free software. You can redistribute it and/or modify it under
+This program is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
-
 1;
